import { Injectable, EventEmitter, Output } from "@angular/core";
import { HttpClient } from "@angular/common/http";
import { Subject } from "rxjs";

@Injectable({ providedIn: "root" })
export class UserService {
	public usersUpdated = new Subject<Boolean>();
	constructor(private http: HttpClient) {}

	// http req to edit user object
	editUser(editedData: any) {
		return this.http.put(`/api/v1/user/${editedData.feide_id}`, editedData);
	}

	// http req to delete user object
	deleteUser(id: string) {
		return this.http.delete(`/api/v1/user/${id}`);
	}

	// returning observable
	getUserUpdateListener() {
		return this.usersUpdated.asObservable();
	}

	// http req to get all users from the database based on pagination
	getUsers(usersPerPage, pageIndex) {
		const paramData = { size: usersPerPage, index: pageIndex };
		return this.http.get<any>("/api/v1/user", { params: paramData });
	}

	// http req to get user count
	getUserCount() {
		return this.http.get<{ count: number }>("/api/v1/user/count");
	}
}
