import { NgModule } from '@angular/core';
import { Routes, RouterModule } from '@angular/router';
import { AdminComponent } from './admin/admin.component';
import { AuthGuard } from './auth/auth.guard';
import { AdminGuard } from './auth/admin.guard' 
import { LoginComponent } from './auth/login/login.component';
import { DashboardComponent } from './dashboard/dashboard.component';
import { FileViewComponent } from './dashboard/file/file-view/file-view.component'
import { NotFoundComponent } from './shared/404/404.component'
import { notactiveComponent } from './shared/notactive/notactive.component';
import { LoggedInGuard } from './auth/loggedIn.guard';
import { FavoritesComponent } from './favorites/favorites.component';
import { FileUploadComponent } from './dashboard/file/file-upload/file-upload.component';
import { UploadStatusComponent } from './dashboard/file/file-upload/upload-status/upload-status.component';

const routes: Routes = [
  { path: 'admin', component: AdminComponent, canActivate: [AdminGuard] },
  { path: 'login', component: LoginComponent, canActivate: [LoggedInGuard]},
  { path: 'favorites', component: FavoritesComponent, canActivate: [AuthGuard]},
  { path: 'upload', component: FileUploadComponent, canActivate: [AuthGuard]},
  { path: '', component: DashboardComponent, canActivate: [AuthGuard], pathMatch: 'full' },
  { path: 'fileview/:sha256', component: FileViewComponent, canActivate: [AuthGuard]}, 
  { path: 'upload/:id', component: UploadStatusComponent, canActivate: [AuthGuard]},
  { path : 'accessdenied' , component: notactiveComponent },
  { path: '**', component: NotFoundComponent }
];

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule],
  providers: [AuthGuard, AdminGuard, LoggedInGuard]
})
export class AppRoutingModule {}
