import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import { FormsModule } from '@angular/forms'
import { HttpClientModule, HTTP_INTERCEPTORS } from '@angular/common/http'
import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';

import { MatFormFieldModule } from '@angular/material/form-field'
import { MatInputModule } from '@angular/material/input'
import { MatOptionModule } from '@angular/material/core'
import { MatSelectModule } from '@angular/material/select'
import { MatButtonModule } from '@angular/material/button'
import { MatIconModule } from '@angular/material/icon'
import { MatCardModule } from '@angular/material/card'
import { MatMenuModule } from '@angular/material/menu'
import { MatDialogModule } from '@angular/material/dialog'
import { MatCheckboxModule } from '@angular/material/checkbox'
import {MatProgressSpinnerModule} from '@angular/material/progress-spinner'
import {MatSidenavModule} from '@angular/material/sidenav'
import {MatSlideToggleModule} from '@angular/material/slide-toggle'
import {MatSnackBarModule} from '@angular/material/snack-bar'
import {MatChipsModule} from '@angular/material/chips'
import {ClipboardModule} from '@angular/cdk/clipboard';
import {LogMonitorModule} from 'ngx-log-monitor';
import { ChartsModule } from 'ng2-charts';
import { FileSaverModule } from 'ngx-filesaver';


import { UserListComponent } from './admin/user-list/user-list.component';
import { MatTableModule } from '@angular/material/table'
import { MatToolbarModule } from '@angular/material/toolbar'
import { animate, state, style, transition, trigger } from '@angular/animations';
import { MatTabsModule } from '@angular/material/tabs'
import { BrowserAnimationsModule } from '@angular/platform-browser/animations'
import { AdminComponent } from './admin/admin.component';
import { HeaderComponent } from './header/header.component';
import { LoginComponent } from './auth/login/login.component';
import { AuthInterceptor } from './auth/auth-interceptor';
import { UserEditDialog } from './admin/user-list/user-list.component'
import { UserDeleteDialog } from './admin/user-list/user-list.component'
import { DashboardComponent } from './dashboard/dashboard.component'
import { LoadingSpinnerComponent} from './shared/loading-spinner/loading-spinner.component'
import { FileListComponent } from './dashboard/file/file-list/file-list.component'
import { MaterialModule } from './material-module'
import { MatPaginatorModule } from '@angular/material/paginator';
import { NgxFilesizeModule } from 'ngx-filesize';
import { FileViewComponent } from './dashboard/file/file-view/file-view.component'
import { NotFoundComponent } from './shared/404/404.component'
import { notactiveComponent } from './shared/notactive/notactive.component';
import { ActionsCardComponent } from './dashboard/file/file-view/file-card/actions-card/actions-card.component';
import { TagsCardComponent } from './dashboard/file/file-view/file-card/tags-card/tags-card.component';
import { SidebarComponent } from './sidebar/sidebar.component';
import { FilterComponent } from './dashboard/file/filter/filter.component'
import { CommonModule } from '@angular/common';  
import { LogComponent } from './admin/log-list/log-list.component'
import { FavoritesComponent } from './favorites/favorites.component';
import { FavoriteListComponent } from './favorites/favorite-list/favorite-list.component'
import { FileUploadComponent } from './dashboard/file/file-upload/file-upload.component';
import { MatFileUploadModule } from 'angular-material-fileupload';
import { InfoCardComponent } from './dashboard/file/file-view/file-card/info-card/info-card.component';
import { VirustotalComponent } from './dashboard/file/file-view/third-party/sources/virustotal/virustotal.component';
import { MatGridListModule } from '@angular/material/grid-list';
import { LayoutModule } from '@angular/cdk/layout';
import { ClassifiedComponent } from './dashboard/file/file-view/third-party/sources/virustotal/classified/classified.component';
import { CardComponent } from './dashboard/file/file-view/third-party/card/card.component';
import { ThirdPartyComponent } from './dashboard/file/file-view/third-party/third-party.component';
import { MalwarebazaarComponent } from './dashboard/file/file-view/third-party/sources/malwarebazaar/malwarebazaar.component';
import { SigningComponent } from './dashboard/file/file-view/third-party/sources/virustotal/signing/signing.component'
import { UploadStatusComponent } from './dashboard/file/file-upload/upload-status/upload-status.component';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import { BindQueryParamDirective } from './dashboard/file/filter/bindQueryParam.directive';
import { StaticAnalysisComponent } from './dashboard/file/file-view/static-analysis/static-analysis.component';
import { PeframeComponent } from './dashboard/file/file-view/static-analysis/sources/peframe/peframe.component'


@NgModule({
  declarations: [
    AppComponent,
    UserListComponent,
    AdminComponent,
    HeaderComponent,
    UserEditDialog,
    LoginComponent,
    DashboardComponent, 
    LoadingSpinnerComponent,
    UserDeleteDialog,
    FileListComponent,
    FileViewComponent,
    NotFoundComponent,
    notactiveComponent,
    ActionsCardComponent,
    TagsCardComponent,
    SidebarComponent,
    FilterComponent,
    LogComponent,
    FavoritesComponent,
    FavoriteListComponent,
    FileUploadComponent,
    InfoCardComponent, 
    VirustotalComponent, 
    ClassifiedComponent,
    CardComponent,
    ThirdPartyComponent,
    MalwarebazaarComponent,
    SigningComponent,
    UploadStatusComponent,
    BindQueryParamDirective,
    StaticAnalysisComponent,
    PeframeComponent
    
  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
    FormsModule,
    BrowserAnimationsModule,
    MatInputModule,
    MatFormFieldModule,
    MatOptionModule,
    MatSelectModule,
    MatButtonModule,
    MatIconModule, 
    MatCardModule,
    MatTableModule,
    HttpClientModule,
    MatToolbarModule,
    MatMenuModule,
    MatDialogModule,
    MatCheckboxModule,
    MatTabsModule, 
    MatProgressSpinnerModule,
    MatSidenavModule,
    MatSlideToggleModule,
    MatSnackBarModule,
    MaterialModule,
    MatPaginatorModule,
    NgxFilesizeModule,
    CommonModule,
    LogMonitorModule,
    MatFileUploadModule,
    ClipboardModule,
    MatGridListModule,
    LayoutModule,
    ChartsModule,
    MatProgressBarModule,
    FileSaverModule
  ],
  providers: [
    { provide: HTTP_INTERCEPTORS, useClass: AuthInterceptor, multi: true}
    //{ provide: HTTP_INTERCEPTORS, useClass: ErrorInterceptor, multi: true}
  ],
  bootstrap: [AppComponent]
})
export class AppModule { }