import {
	CanActivate,
	ActivatedRouteSnapshot,
	RouterStateSnapshot,
	Router,
} from "@angular/router";
import { Injectable } from "@angular/core";
import { Subscription } from "rxjs";
import {
	HttpClient,
	HttpHeaders,
	HttpClientModule,
} from "@angular/common/http";
import { AuthService } from "./auth.service";

@Injectable()
export class AdminGuard implements CanActivate {
	user;
	userIsAuthenticated = false;
	private authListnerSubs: Subscription;
	constructor(
		private authService: AuthService,
		private router: Router,
		private http: HttpClient
	) {}

	canActivate(
		route: ActivatedRouteSnapshot,
		state: RouterStateSnapshot
	): Promise<boolean> {
		return new Promise((resolve) => {
			this.authListnerSubs = this.authService
				.getAuthStatusListener()
				.subscribe((isAuthenticated) => {
					this.userIsAuthenticated = isAuthenticated;
				});

			if (this.userIsAuthenticated) {
				// Checking if global var isAuth is set
				resolve(true);
			} else {
				this.http
					.get("/api/v1/user/profile") // is not, pull profile
					.subscribe(
						(user: any) => {
							if (user && user.active && user.authored) {
								// check if user exist on session and is active
								this.authService.user = user;
								this.authService.authStatusListner.next(true);
								if (user.role == "admin") {
									resolve(true);
								} else {
									this.router.navigate(["/"]);
									resolve(false);
								} // permit user
							} else {
								if (!user.active || !user.authored) {
									// check if user is not active
									console.log("User must talk to an admin");
									// redirect to notactive to tell user to talk to an admin
									this.router.navigate(["/accessdenied"]); 
									this.authService.authStatusListner.next(false);
									resolve(false);
								} else {
									// user profile does not exist on session, redirect to login
									console.log("User is not authenticated, redirecting..."); 
									this.authService.authStatusListner.next(false);
									this.router.navigate(["/login"]);
									resolve(false);
								}
							}
						},
						(error) => {
							// all unknown errors redirect to login, typical for user does not exist in db etc
							console.log("User is not authenticated, redirecting."); 
							this.router.navigate(["/login"]);
						}
					);
			}
		});
	}
}
