import { Injectable } from "@angular/core";
import {
	ActivatedRouteSnapshot,
	CanActivate,
	Router,
	RouterStateSnapshot,
} from "@angular/router";
import { AuthService } from "./auth.service";
import { Subscription } from "rxjs";
import {
	HttpClient,
	HttpHeaders,
	HttpClientModule,
} from "@angular/common/http";
import { Console } from "console";
import { getMatInputUnsupportedTypeError } from "@angular/material/input";

@Injectable({
	providedIn: "root",
})
export class AuthGuard implements CanActivate {
	userIsAuthenticated = false;
	private authListnerSubs: Subscription;
	constructor(
		private authService: AuthService,
		private router: Router,
		private http: HttpClient
	) {}

	canActivate(
		route: ActivatedRouteSnapshot,
		state: RouterStateSnapshot
	): Promise<boolean> {
		return new Promise((resolve) => {
			this.authListnerSubs = this.authService
				.getAuthStatusListener()
				.subscribe((isAuthenticated) => {
					this.userIsAuthenticated = isAuthenticated;
				});

			if (this.userIsAuthenticated) {
				// Checking if global var isAuth is set
				resolve(true);
			} 
            // is not, pull profile
            else {
				this.http
					.get("/api/v1/user/profile") 
					.subscribe(
						(user: any) => {
                            // check if user exist on session and is active
							if (user && user.active && user.authored) {
								this.authService.user = user;
								console.log("Auth guard: User authenticated");
								this.authService.authStatusListner.next(true);
								resolve(true); // permit user
							} else {
                                // check if user is not active
								if (!user.active || !user.authored) {
									console.log("User must talk to an admin");
                                    // redirect to notactive to tell user to talk to an admin
									this.router.navigate(["/accessdenied"]); 
									this.authService.authStatusListner.next(false);
									resolve(false);
								} 
                                // user profile does not exist on session, redirect to login
                                else {
									console.log("User is not authenticated, redirecting..."); 
									this.authService.authStatusListner.next(false);
									this.router.navigate(["/login"]);
									resolve(false);
								}
							}
						},
						(error) => {
                            // all unknown errors redirect to login, typical for user does not exist in db etc
							console.log("User is not authenticated, redirecting."); 
							this.router.navigate(["/login"]);
						}
					);
			}
		});
	}
}
