import { Injectable, EventEmitter, Output } from "@angular/core";
import {
	HttpClient,
	HttpHeaders,
	HttpClientModule,
} from "@angular/common/http";
import { AuthData } from "./auth-data.model";
import { Router } from "@angular/router";
import { User } from "../models/user";
import { catchError, map } from "rxjs/operators";
import { BehaviorSubject, of } from "rxjs";
import { Subject } from "rxjs";
import { TmplAstRecursiveVisitor } from "@angular/compiler";

const httpOptions = {
	headers: new HttpHeaders({
		mode: "no-cors",
	}),
};

@Injectable({ providedIn: "root" })
export class AuthService {
	authStatusListner = new Subject<boolean>();
	isAuthenticated = false;
	public user;
	public subscription$;

	constructor(private http: HttpClient, private router: Router) {}

	getAuthStatusListener() {
		return this.authStatusListner.asObservable();
	}

	getUserProfile() {
		this.http
			.get("/api/v1/user/profile") // is not, pull profile
			.subscribe(
				(user: any) => {
					if (user && user.active && user.authored) {
						// check if user exist on session and is active
						this.user = user;
						// permit user
						this.authStatusListner.next(true); 
					} else {
						if (!user.active || !user.authored) {
							// check if user is not active
							this.authStatusListner.next(false);
						} else {
							this.authStatusListner.next(false);
						}
					}
				},
				(error) => {
                    // all unknown errors redirect to login, typical for user does not exist in db etc
					console.log("User is not authenticated, redirecting."); 
					this.router.navigate(["/login"]);
				}
			);
	}

	updateAuthenticated(status: boolean) {
		console.log("Updating isAuthenticated to, ", status);
		this.authStatusListner.next(status);
	}

	public signout() {
		this.updateAuthenticated(false);
	}
}
