import { Component, Input, OnInit, Renderer2, SimpleChanges, ElementRef} from '@angular/core';
import { webSocket, WebSocketSubject } from 'rxjs/webSocket';
import { Observable } from 'rxjs';
import { Router, ActivatedRoute, Params } from '@angular/router'

@Component({
  selector: 'app-upload-status',
  templateUrl: './upload-status.component.html',
  styleUrls: ['./upload-status.component.scss']
})

export class UploadStatusComponent{

  constructor(private activatedRoute: ActivatedRoute, private renderer: Renderer2,private router: Router, private el: ElementRef) {}

  public id: string;
  public progressValue
  @Input() dataSource: string = ''

  ngOnInit() {
    // Note: Below 'queryParams' can be replaced with 'params' depending on your requirements
    this.id = this.activatedRoute.snapshot.paramMap.get('id');

    const protocol = window.location.protocol.replace('http', 'ws');
    // get location host
    const host = window.location.host;

    // connect to websocket
    webSocket(`${protocol}//${host}/ws/upload/${this.id}`)
      .subscribe(msg => {
        this.dataSource = JSON.stringify(msg, null, 2)
        this.setProgressValue()
      })
    
  }

  ngOnChanges(changes : SimpleChanges) {
    //let change = changes.dataSource
    this.setProgressValue()

  }

  // setting progress value on the progress-bar
  setProgressValue() {
    let object = JSON.parse(this.dataSource)
    if (object?.added_storage) {
      this.progressValue = 100
    } else if (object?.analyzed) {
      this.progressValue = 75
    } else if (object?.added_database) {
      this.progressValue = 50
    } else if (object?.unzipped) {
      this.progressValue = 25
    }
  }
}
