import { Injectable } from '@angular/core';
import { HttpClient, HttpParams } from '@angular/common/http'
import { File } from './file-list/file-list.model' 
import { Observable, Subject } from 'rxjs'
import { FileData } from './file-list/file-list.model'
import { ActivatedRoute } from '@angular/router';

@Injectable({ providedIn: "root" })

export class FileService {
    public filesUpdated = new Subject<Boolean>()
    constructor(private http: HttpClient,  private route: ActivatedRoute) {}

    getPageFiles(filesPerPage, pageIndex) {
        const search = this.route.snapshot.queryParams
        const pagination = {size: filesPerPage, index: pageIndex};
        let paramData = {...pagination, ...search}
        return this.http.get<any>("/api/v1/file",{params: paramData})
    }

    getFilesUpdateListner() {
        return this.filesUpdated.asObservable()
    }

    getFileCount() {
        return this.http.get<{count: number}>("/api/v1/file/count")
    }

    getFile( sha256: string): Observable<any> {
        let params = new HttpParams().set('sha256', sha256)
        return this.http.get(`/api/v1/file/${sha256}`, { params: params }) 
    }

    reanalyze( sha256, source: string ): Observable<any> {
        const data = { hash: sha256, analyze_source: source }       
        return this.http.post(`/api/v1/file/reanalyze`, data)       
    }

    downloadFiles(hashes) {
        return this.http.post(`/api/v1/file/download`,{ files: hashes }, {responseType: "blob"})
    }
}