import { Component, ViewChild, AfterViewInit } from '@angular/core'
import { File } from '../../dashboard/file/file-list/file-list.model'
import { FavoriteService } from '../favorite.service'
import { Subscription } from 'rxjs'
import { animate, state, style, transition, trigger } from '@angular/animations';
import { PageEvent } from '@angular/material/paginator'
import { MatSort, Sort } from '@angular/material/sort'
import { MatTableDataSource } from '@angular/material/table';

@Component({
  selector: 'app-favorite-list',
  templateUrl: './favorite-list.component.html',
  styleUrls: ['./favorite-list.component.scss'],
  animations: [
    trigger('detailExpand', [
      state('collapsed, void', style({height: '0px', minHeight: '0'})),
      state('expanded', style({height: '*'})),
      transition('expanded <=> collapsed, void => expanded', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)')),
    ]),
  ],
})

export class FavoriteListComponent{
  displayedColumns: string[] = ['original_filename', 'filetype', 'size', 'date_added'];
  files: File[] = []
  isLoadingResults = true
  expandedFile: File | null
  numberOfFiles = 10
  filesPerPage = 25
  pageIndex = 0
  pageSizeOption = [2, 5, 10, 25]
  dataSource = new MatTableDataSource(this.files);

  private filesSub: Subscription
  constructor(public favoriteService: FavoriteService) {}

  @ViewChild(MatSort) sort: MatSort;

  ngOnInit() {
    // get the number of favorites from the db
    this.favoriteService.getFavoriteCount()
        .subscribe((fileCount) => {
            this.numberOfFiles = fileCount.count
        })
    // get files
    this.getFileList()
    this.filesSub = this.favoriteService.getFavoritesUpdateListner()
        .subscribe(() => {
            this.getFileList()
            console.log("New file(s) uploaded")
        })
  }

  ngAfterViewInit() {
      this.dataSource.sort = this.sort;
    } 

  ngOnDestroy() {
      this.filesSub.unsubscribe()
  }

  getFileList() {
      this.isLoadingResults = true
      // get files based on pagination
      this.favoriteService.getFavoriteFiles(this.filesPerPage, this.pageIndex)
          .subscribe((fileList) => {
              //populate table
              this.dataSource = new MatTableDataSource(fileList.files);
              // sort the table
              this.dataSource.sortingDataAccessor = (item, property) => {
                  if(!item[property]) {
                      return this.sort.direction === "asc" ? '3' : '1'
                  }
                  return '2' + item[property].toLocaleLowerCase()
              }
              this.dataSource.sort = this.sort;
              this.isLoadingResults = false
          })
  }

  //Runs when changing pages in the filelist
  onPageChange(pageData: PageEvent) {        
      this.filesPerPage = pageData.pageSize
      this.pageIndex = pageData.pageIndex
      this.getFileList()
  }
}