const fileUpload = require('express-fileupload')
var session = require('express-session')
var MemoryStore = require('memorystore')(session)
const cors = require('cors')
const express = require('express')
const passport = require('passport')
const port = 3000
const {authorize} = require('./auth/passport-openid-connect/lib/authorize')
var OICStrategy = require('./auth/passport-openid-connect').Strategy

require('./dev-config')

require('./startup')()
require('./db/pipeline-service')
require('./pipeline/virustotal/virustotal')
require('./pipeline/selfupload')
require('./db/connect')()
require('./passport')(passport)

var app = express()
var expressWs = require("express-ws")
expressWs(app, null, {
  perMessageDeflate: false,
});
app.use(express.json())
app.use(cors())
app.use(session({
  cookie: { maxAge: 60 * 60 * 8 * 1000 }, // Set expiration to 8hrs as per Feide documentaion
  store: new MemoryStore({
    checkPeriod: 60 * 60 * 8 * 1000 // prune expired entries every 8hrsh
  }),
  resave: false,
  secret: process.env.express_secret,
  saveUninitialized: true
}));

// Dataporten passport setup for authentication and authorization
var oic = new OICStrategy({
    "issuerHost": process.env.dataporten_host,
    "client_id": process.env.dataporten_client_id,
    "client_secret": process.env.dataporten_client_secret,
    "redirect_uri": process.env.dataporten_redirect_uri,
    "scope": process.env.dataporten_scope
  });

// set passport options
passport.use(oic)
passport.serializeUser(OICStrategy.serializeUser)
passport.deserializeUser(OICStrategy.deserializeUser)

// tell express to use passport
app.use(passport.initialize());
app.use(passport.session());

app.get('/auth/login', passport.authenticate('passport-openid-connect', {session: false}, {"successReturnToOrRedirect": "/"}))
app.get('/auth/callback', passport.authenticate('passport-openid-connect', {"callback": true, "successReturnToOrRedirect": process.env.dataporten_returnto}))

app.get('/auth/logout',(req, res) => {
	req.session.destroy()
	//TODO fiks req.user.token avhengighet
	res.redirect(`https://auth.dataporten.no/openid/endsession?id_token_hint=${req.user.token.id_token}&post_logout_redirect_uri=http%3A%2F%2F${process.env.dataporten_redirect_uriencoded}%2Flogin`)
})

// Route initialization and specification
app.use('/api', require('./api')(app, express, passport))
app.use('/ws', require('./api/ws')(app, express, passport))
app.use(fileUpload({
	createParentPath: true
}));

app.listen(port, () => {
	console.log(`REST API running and listening on port ${port}`)
})

module.exports = app
module.exports.passport = passport