const userService = require('../../../db/user-service')
var openid = require('openid-client')
var passport = require('passport')
var util = require('util')
const request = require('request')
var User = require('./User').User

var OICStrategy = function(config) {
	this.name = 'passport-openid-connect'
	this.config = config || {}
	this.groupsUrl = 'https://groups-api.dataporten.no/groups/me/groups'
	this.client = null
	this.tokenSet = null
	this.init()
		.then(() => {
			console.log("Initialization of OpenID Connect discovery process completed.")
		})
}
util.inherits(OICStrategy, passport.Strategy)

OICStrategy.prototype.init = function() {
	if (!this.config.issuerHost) {
		throw new Error("Could not find requried config options issuerHost in openid-passport strategy initalization")
	}
	return Promise.resolve().then(() => {
		return openid.Issuer.discover(this.config.issuerHost)
	})
		.then((issuer) => {
			this.client = new issuer.Client(this.config)
		})
		.catch((err) => {
			console.error("ERROR", err);
		})
}

OICStrategy.prototype.authenticate = function(req, opts) {
	if (opts.callback) {
		return this.callback(req, opts)
	}
	try {
		var authurl = this.client.authorizationUrl(this.config)
		this.redirect(authurl)
	} catch (error) {
		//TODO finn ut en måte å se om dette funker
		console.error("Error getting authUrl", error);
		this.fail(error)
	}
	
	
}

OICStrategy.prototype.getUserInfo = function() {
	return this.client.userinfo(this.tokenSet.access_token)
		.then((userinfo) => {
			this.userinfo = userinfo
		})
}

OICStrategy.prototype.loadGroups = function() {
	var that = this;										// Workaround for accessing 'this' inside a subfunction, promise.
	return new Promise(function(resolve, reject) {

		var options = {
			url: that.groupsUrl,
			headers: {
				'User-Agent': 'passport-dataporten',
				'Authorization': 'Bearer ' + that.tokenSet.access_token
			}
		};
		// console.log("Perforing OAuth 2.0 Request", options);
		request(options, function (error, response, body) {	// Send request to groups API
			if (!error && response.statusCode == 200) {
				var data = JSON.parse(body);
				resolve(data);								// Resolve with data
			}
			reject(error);									// Reject if error
		});

	}).then(function(groups) {
		that.groups = groups;
		return groups;
	});
};


OICStrategy.prototype.callback = function(req, opts) {
	return this.client.callback(this.config.redirect_uri, req.query)
		.then((tokenSet) => {								// Get users basic information
			this.tokenSet = tokenSet
			return this.getUserInfo()
		})
		.then(() => {										// Get users groups
			return this.loadGroups()
		})
		.then(() => {										// Set user object with user-data
			var user = new User(this.userinfo)
			user.token = this.tokenSet
			user.idtoken = this.tokenSet.claims
			user.groups = this.groups
			this.success(user)
		})
		.catch((err) => {
			console.error("Error processing callback", err);
			this.fail(err)
		})
}

OICStrategy.serializeUser = function(user, cb) {
	// Find the user in the database based on their feide_id
	userService.findUser(user.data.sub)
		.then(usr => {
			// if user exist, serialize the user to a session
			if (usr) {
				cb(null, user.serialize());
			}
			// if the user does not exist, create it in the
			// database and serialize the user to a session
			else {
				userService.createUser(user)
					.then(data => {
						cb(null, user.serialize());
					})
			}
		})
		.catch(err => {
			this.fail(err)
		})
}
OICStrategy.deserializeUser = function(packed, cb) {
	
	userService.findUser(packed.data.sub)
		.then(usr => {
			packed.db = usr
			cb(null, User.unserialize(packed))
		})
	

}


exports.Strategy = OICStrategy