/**
 * @desc Authorization-check for backend
 * @params req, res, args (request, response and arguments)
 * @res Will return true if authenticated/authorized, and send an immediate 401/403 if unauth.
 */
module.exports.authorize = function (args) {
	return (req, res, next) => {
		let allowedRole = [];
		let allowedTags = [];
		let allowAll = false;

		// Check if req.user is on request, and user is active
		if (req.user && req.user.db.active) {
			// Set 'all' from middleware
			if (args.all != undefined) {
				allowAll = args.all;
			}

			// Set role from middleware
			if (args.role != undefined) {
				allowedRole = args.role;
			}

			// Set tags from middleware
			if (args.tags != undefined) {
				allowedTags = args.tags;
			}

			// User is authenticated, data set, start checking for authorization
			exec();
		} else {
			// User did not have a session, or inactive, unauthenticated
			return res.status(401).json({
				message: "Unauthorized",
			});
		}

		/**
		 * @desc Authorization-check for backend
		 * @params req, res, args (request, response and arguments)
		 * @res Will return true if authenticated/authorized, and send an immediate 401/403 if unauth.
		 */
		function exec() {
			// Check if "any: true " is passed
			if (allowAllAuthenticated()) {
				return next();
			}

			// Check if users role is in the routes groups
			else if (isUserRoleAllowed(req.user.db.role)) {
				return next();
			}

			// Check if users tags is in the routes tags
			else if (isAnyUserTagsAllowed(req.user.db.tags)) {
				return next();
			}

			// User not authorized
			else {
				return res.status(401).json({
					message: "Unauthorized",
				});
			}
		}

		/**
		 * @desc Check if specifictag is allowed
		 * @params userTag - Users tag to check
		 * @res Will return true if the users tag is in the list of allowed tags passed from middleware
		 */
		function isTagAllowed(userTag) {
			for (var i = 0; i < allowedTags.length; i++) {
				if (allowedTags[i] == userTag) {
					return true;
				}
			}
			return false;
		}

		/**
		 * @desc Check if any tag is allowed
		 * @params userTags[]
		 * @res Will return true if any tags is in the list of allowed tags passed from middleware
		 */
		function isAnyUserTagsAllowed(userTags) {
			for (var i = 0; i < userTags.length; i++) {
				if (isTagAllowed(userTags[i])) {
					return true;
				}
			}
			return false;
		}

		/**
		 * @desc Check if any role is allowed
		 * @params role[]
		 * @res Will return true if any role is in the whitelisted IDs passed to authorize.js
		 */
		function isUserRoleAllowed(userRole) {
			for (var i = 0; i < allowedRole.length; i++) {
				if (allowedRole[i] == userRole) {
					return true;
				}
			}
			return false;
		}

		/**
		 * @desc Check if anyone is allowed
		 * @res Will return true if the "all" flag is passed
		 */
		function allowAllAuthenticated() {
			if (allowAll) {
				return true;
			}
		}
	};
};
